# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "ca_material": "caMaterial",
    "cert_material": "certMaterial",
    "cert_path": "certPath",
    "check_duplicate": "checkDuplicate",
    "container_logs": "containerLogs",
    "converge_config": "convergeConfig",
    "cpu_set": "cpuSet",
    "cpu_shares": "cpuShares",
    "destroy_grace_seconds": "destroyGraceSeconds",
    "dns_opts": "dnsOpts",
    "dns_searches": "dnsSearches",
    "driver_opts": "driverOpts",
    "endpoint_spec": "endpointSpec",
    "exit_code": "exitCode",
    "ip_address": "ipAddress",
    "ip_prefix_length": "ipPrefixLength",
    "ipam_configs": "ipamConfigs",
    "ipam_driver": "ipamDriver",
    "keep_locally": "keepLocally",
    "key_material": "keyMaterial",
    "log_driver": "logDriver",
    "log_opts": "logOpts",
    "max_retry_count": "maxRetryCount",
    "memory_swap": "memorySwap",
    "must_run": "mustRun",
    "network_aliases": "networkAliases",
    "network_datas": "networkDatas",
    "network_mode": "networkMode",
    "networks_advanced": "networksAdvanced",
    "pid_mode": "pidMode",
    "publish_all_ports": "publishAllPorts",
    "pull_trigger": "pullTrigger",
    "pull_triggers": "pullTriggers",
    "registry_auth": "registryAuth",
    "rollback_config": "rollbackConfig",
    "server_address": "serverAddress",
    "task_spec": "taskSpec",
    "update_config": "updateConfig",
    "userns_mode": "usernsMode",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "caMaterial": "ca_material",
    "certMaterial": "cert_material",
    "certPath": "cert_path",
    "checkDuplicate": "check_duplicate",
    "containerLogs": "container_logs",
    "convergeConfig": "converge_config",
    "cpuSet": "cpu_set",
    "cpuShares": "cpu_shares",
    "destroyGraceSeconds": "destroy_grace_seconds",
    "dnsOpts": "dns_opts",
    "dnsSearches": "dns_searches",
    "driverOpts": "driver_opts",
    "endpointSpec": "endpoint_spec",
    "exitCode": "exit_code",
    "ipAddress": "ip_address",
    "ipPrefixLength": "ip_prefix_length",
    "ipamConfigs": "ipam_configs",
    "ipamDriver": "ipam_driver",
    "keepLocally": "keep_locally",
    "keyMaterial": "key_material",
    "logDriver": "log_driver",
    "logOpts": "log_opts",
    "maxRetryCount": "max_retry_count",
    "memorySwap": "memory_swap",
    "mustRun": "must_run",
    "networkAliases": "network_aliases",
    "networkDatas": "network_datas",
    "networkMode": "network_mode",
    "networksAdvanced": "networks_advanced",
    "pidMode": "pid_mode",
    "publishAllPorts": "publish_all_ports",
    "pullTrigger": "pull_trigger",
    "pullTriggers": "pull_triggers",
    "registryAuth": "registry_auth",
    "rollbackConfig": "rollback_config",
    "serverAddress": "server_address",
    "taskSpec": "task_spec",
    "updateConfig": "update_config",
    "usernsMode": "userns_mode",
}
